@@ -55,6 +55,8 @@
 #include "burn-task.h"
 #include "brasero-caps-burn.h"
 
+#include "brasero-drive-priv.h"
+
 #include "brasero-volume.h"
 #include "brasero-drive.h"
 
@@ -260,7 +262,6 @@ static BraseroBurnResult
 brasero_burn_reprobe (BraseroBurn *burn)
 {
 	guint attempts = 0;
-	BraseroMedium *medium;
 	BraseroBurnPrivate *priv;
 	BraseroBurnResult result = BRASERO_BURN_OK;
 
@@ -270,7 +271,7 @@ brasero_burn_reprobe (BraseroBurn *burn)
 
 	/* reprobe the medium and wait for it to be probed */
 	brasero_drive_reprobe (priv->dest);
-	while (attempts < MAX_REPROBE_ATTEMPTS && (medium = brasero_drive_get_medium (priv->dest)) == NULL) {
+	while (attempts < MAX_REPROBE_ATTEMPTS && brasero_drive_probing (priv->dest)) {
 		result = brasero_burn_sleep (burn, 250);
 		attempts ++;
 	}
@@ -278,6 +279,44 @@ brasero_burn_reprobe (BraseroBurn *burn)
 	return result;
 }
 
+static BraseroBurnResult
+brasero_burn_unmount (BraseroBurn *self,
+                      BraseroMedium *medium,
+                      GError **error)
+{
+	guint counter = 0;
+
+	if (!medium)
+		return BRASERO_BURN_OK;
+
+	/* Retry several times, since sometimes the drives are really busy */
+	while (brasero_volume_is_mounted (BRASERO_VOLUME (medium))) {
+		BraseroBurnResult result;
+
+		counter ++;
+		if (counter > MAX_EJECT_ATTEMPTS) {
+			BRASERO_BURN_LOG ("Max attempts reached at unmounting");
+			if (error && !(*error))
+				g_set_error (error,
+					     BRASERO_BURN_ERROR,
+					     BRASERO_BURN_ERROR_DRIVE_BUSY,
+					     "%s. %s",
+					     _("The drive is busy"),
+					     _("Make sure another application is not using it"));
+			return BRASERO_BURN_ERR;
+		}
+
+		BRASERO_BURN_LOG ("Retrying unmounting");
+		result = brasero_volume_umount (BRASERO_VOLUME (medium), TRUE, NULL);
+		if (result != BRASERO_BURN_OK)
+			return result;
+
+		brasero_burn_sleep (self, 500);
+	}
+
+	return BRASERO_BURN_OK;
+}
+
 static BraseroBurnResult
 brasero_burn_eject (BraseroBurn *self,
 		    BraseroDrive *drive,
@@ -1174,13 +1213,10 @@ brasero_burn_progress_changed (BraseroTaskCtx *task,
 			       BraseroBurn *burn)
 {
 	BraseroBurnPrivate *priv = BRASERO_BURN_PRIVATE (burn);
-	BraseroBurnAction action = BRASERO_BURN_ACTION_NONE;
 	gdouble overall_progress = -1.0;
 	gdouble task_progress = -1.0;
 	glong time_remaining = -1;
 
-	brasero_task_ctx_get_current_action (task, &action);
-
 	/* get the task current progress */
 	if (brasero_task_ctx_get_progress (task, &task_progress) == BRASERO_BURN_OK) {
 		brasero_task_ctx_get_remaining_time (task, &time_remaining);
@@ -1370,23 +1406,30 @@ brasero_burn_run_eraser (BraseroBurn *burn, GError **error)
 	BraseroDrive *drive;
 	BraseroMedium *medium;
 	BraseroBurnPrivate *priv;
+	BraseroBurnResult result;
 
 	priv = BRASERO_BURN_PRIVATE (burn);
 
 	drive = brasero_burn_session_get_burner (priv->session);
 	medium = brasero_drive_get_medium (drive);
-	if (brasero_volume_is_mounted (BRASERO_VOLUME (medium))
-	&& !brasero_volume_umount (BRASERO_VOLUME (medium), TRUE, NULL)) {
-		g_set_error (error,
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_DRIVE_BUSY,
-			     "%s. %s",
-			     _("The drive is busy"),
-			     _("Make sure another application is not using it"));
-		return BRASERO_BURN_ERR;
-	}
 
-	return brasero_task_run (priv->task, error);
+	result = brasero_burn_unmount (burn, medium, error);
+	if (result != BRASERO_BURN_OK)
+		return result;
+
+	result = brasero_task_run (priv->task, error);
+	if (result != BRASERO_BURN_OK)
+		return result;
+
+	/* Reprobe. It can happen (like with dvd+rw-format) that
+	 * for the whole OS, the disc doesn't exist during the 
+	 * formatting. Wait for the disc to reappear */
+	/*  Likewise, this is necessary when we do a
+	 * simulation before blanking since it blanked the disc
+	 * and then to create all tasks necessary for the real
+	 * burning operation, we'll need the real medium status 
+	 * not to include a blanking job again. */
+	return brasero_burn_reprobe (burn);
 }
 
 static BraseroBurnResult
@@ -1406,18 +1449,11 @@ brasero_burn_run_imager (BraseroBurn *burn,
 start:
 
 	medium = brasero_drive_get_medium (src);
-
-	/* This is just in case */
-	if (medium
-	&&  brasero_volume_is_mounted (BRASERO_VOLUME (medium))
-	&& !brasero_volume_umount (BRASERO_VOLUME (medium), TRUE, NULL)) {
-		g_set_error (error,
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_DRIVE_BUSY,
-			     "%s. %s",
-			     _("The drive is busy"),
-			     _("Make sure another application is not using it"));
-		return BRASERO_BURN_ERR;
+	if (medium) {
+		/* This is just in case */
+		result = brasero_burn_unmount (burn, medium, error);
+		if (result != BRASERO_BURN_OK)
+			return result;
 	}
 
 	/* If it succeeds then the new track(s) will be at the top of
@@ -1578,29 +1614,15 @@ brasero_burn_run_recorder (BraseroBurn *burn, GError **error)
 start:
 
 	/* this is just in case */
-	if (BRASERO_BURN_SESSION_NO_TMP_FILE (priv->session)
-	&&  src_medium
-	&&  brasero_volume_is_mounted (BRASERO_VOLUME (src_medium))
-	&& !brasero_volume_umount (BRASERO_VOLUME (src_medium), TRUE, NULL)) {
-		g_set_error (error,
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_DRIVE_BUSY,
-			     "%s. %s",
-			     _("The drive is busy"),
-			     _("Make sure another application is not using it"));
-		return BRASERO_BURN_ERR;
+	if (BRASERO_BURN_SESSION_NO_TMP_FILE (priv->session)) {
+		result = brasero_burn_unmount (burn, src_medium, error);
+		if (result != BRASERO_BURN_OK)
+			return result;
 	}
 
-	if (brasero_volume_is_mounted (BRASERO_VOLUME (burnt_medium))
-	&& !brasero_volume_umount (BRASERO_VOLUME (burnt_medium), TRUE, NULL)) {
-		g_set_error (error,
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_DRIVE_BUSY,
-			     "%s. %s",
-			     _("The drive is busy"),
-			     _("Make sure another application is not using it"));
-		return BRASERO_BURN_ERR;
-	}
+	result = brasero_burn_unmount (burn, burnt_medium, error);
+	if (result != BRASERO_BURN_OK)
+		return result;
 
 	/* before we start let's see if that drive can be used exclusively.
 	 * Of course, it's not really safe since a process could take a lock
@@ -1979,18 +2001,6 @@ brasero_burn_run_tasks (BraseroBurn *burn,
 				if (result != BRASERO_BURN_OK)
 					break;
 
-				/* Reprobe. It can happen (like with dvd+rw-format) that
-				 * for the whole OS, the disc doesn't exist during the 
-				 * formatting. Wait for the disc to reappear */
-				/*  Likewise, this is necessary when we do a
-				 * simulation before blanking since it blanked the disc
-				 * and then to create all tasks necessary for the real
-				 * burning operation, we'll need the real medium status 
-				 * not to include a blanking job again. */
-				result = brasero_burn_reprobe (burn);
-				if (result != BRASERO_BURN_OK)
-					break;
-
 				/* Since we blanked/formatted we need to recheck the burn 
 				 * flags with the new medium type as some flags could have
 				 * been given the benefit of the double (MULTI with a CLOSED
@@ -2102,10 +2112,10 @@ brasero_burn_check_real (BraseroBurn *self,
 	 * means the checksum file is on the disc. */
 	medium = brasero_drive_get_medium (priv->dest);
 
-	/* get the task and run it */
+	/* get the task and run it skip it otherwise */
 	priv->task = brasero_burn_caps_new_checksuming_task (priv->caps,
 							     priv->session,
-							     error);
+							     NULL);
 	if (priv->task) {
 		priv->task_nb = 1;
 		priv->tasks_done = 0;
@@ -2152,7 +2162,7 @@ brasero_burn_check_real (BraseroBurn *self,
 	}
 	else {
 		BRASERO_BURN_LOG ("The track cannot be checked");
-		result = BRASERO_BURN_NOT_SUPPORTED;
+		return BRASERO_BURN_OK;
 	}
 
 	return result;
