@@ -1,24 +1,28 @@
-/***************************************************************************
- *            burn-local-image.c
- *
- *  dim jui  9 10:54:14 2006
- *  Copyright  2006  Rouquier Philippe
- *  brasero-app@wanadoo.fr
- ***************************************************************************/
-
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- *  Brasero is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * Libbrasero-burn
+ * Copyright (C) Philippe Rouquier 2005-2009 <bonfire-app@wanadoo.fr>
  *
- *  Brasero is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * Libbrasero-burn is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to:
+ * The Libbrasero-burn authors hereby grant permission for non-GPL compatible
+ * GStreamer plugins to be used and distributed together with GStreamer
+ * and Libbrasero-burn. This permission is above and beyond the permissions granted
+ * by the GPL license by which Libbrasero-burn is covered. If you modify this code
+ * you may extend this exception to your version of the code, but you are not
+ * obligated to do so. If you do not wish to do so, delete this exception
+ * statement from your version.
+ * 
+ * Libbrasero-burn is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to:
  * 	The Free Software Foundation, Inc.,
  * 	51 Franklin Street, Fifth Floor
  * 	Boston, MA  02110-1301, USA.
@@ -353,7 +357,7 @@ error:
 static BraseroBurnResult
 brasero_local_track_update_track (BraseroLocalTrack *self)
 {
-	BraseroTrack *track;
+	BraseroTrack *track = NULL;
 	BraseroTrack *current = NULL;
 	BraseroLocalTrackPrivate *priv;
 
@@ -409,7 +413,7 @@ brasero_local_track_update_track (BraseroLocalTrack *self)
 				unreadable = g_slist_remove (unreadable, unreadable->data);
 		}
 	}
-	else if (BRASERO_IS_TRACK_STREAM (track)) {
+	else if (BRASERO_IS_TRACK_STREAM (current)) {
 		gchar *uri;
 		gchar *newuri;
 
@@ -426,7 +430,7 @@ brasero_local_track_update_track (BraseroLocalTrack *self)
 						     brasero_track_stream_get_gap (BRASERO_TRACK_STREAM (current)));
 		g_free (uri);
 	}
-	else if (BRASERO_IS_TRACK_IMAGE (track)) {
+	else if (BRASERO_IS_TRACK_IMAGE (current)) {
 		gchar *uri;
 		gchar *newtoc;
 		gchar *newimage;
@@ -586,7 +590,7 @@ brasero_local_track_start_thread (BraseroLocalTrack *self,
 	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_local_track_thread,
 					self,
-					TRUE,
+					FALSE,
 					&thread_error);
 	g_mutex_unlock (priv->mutex);
 
